# Dynamic Web Application (DWA)

<badges>[![version](https://img.shields.io/pypi/v/dwa.svg)](https://pypi.org/project/dwa/)
[![license](https://img.shields.io/pypi/l/dwa.svg)](https://pypi.org/project/dwa/)
[![pyversions](https://img.shields.io/pypi/pyversions/dwa.svg)](https://pypi.org/project/dwa/)  
[![donate](https://img.shields.io/badge/Donate-Paypal-0070ba.svg)](https://paypal.me/foxe6)
[![powered](https://img.shields.io/badge/Powered%20by-UTF8-red.svg)](https://paypal.me/foxe6)
[![made](https://img.shields.io/badge/Made%20with-PyCharm-red.svg)](https://paypal.me/foxe6)
</badges>

<i>Dynamic Web Application (DWA) framework written with Tornado.</i>

# Hierarchy

```
dwa
```

# Example
See [dwa/example/test.py](dwa/example).
